==> hubzero-submit-pegasus_4.5.2-3+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/funding_citing_usage.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="cpu_affinity_condor.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="usage_statistics.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="chapter">
<div class="titlepage"><div><div><h1 class="title">
<a name="funding_citing_usage"></a>Chapter 17. Funding, citing, and anonymous usage statistics</h1></div></div></div>
<div class="toc"><dl class="toc">
<dt><span class="section"><a href="funding_citing_usage.php#citing">17.1. Citing Pegasus in Academic Works</a></span></dt>
<dt><span class="section"><a href="usage_statistics.php">17.2. Usage Statistics Collection</a></span></dt>
</dl></div>
<div class="section">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="citing"></a>17.1. Citing Pegasus in Academic Works</h2></div></div></div>
<p>The preferred generic way to cite Pegasus is:</p>
<p><span class="emphasis"><em>Pegasus: a Framework for Mapping Complex Scientific
    Workflows onto Distributed Systems, Ewa Deelman, Gurmeet Singh, Mei-Hui
    Su, James Blythe, Yolanda Gil, Carl Kesselman, Gaurang Mehta, Karan Vahi,
    G. Bruce Berriman, John Good, Anastasia Laity, Joseph C. Jacob, Daniel S.
    Katz. Scientific Programming Journal, Vol 13(3), 2005, Pages
    219-237.</em></span></p>
</div>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="cpu_affinity_condor.php">Prev</a> </td>
<td width="20%" align="center"> </td>
<td width="40%" align="right"> <a accesskey="n" href="usage_statistics.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">16.5. Slot Partitioning and CPU Affinity in Condor </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 17.2. Usage Statistics Collection</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>

==> hubzero-submit-pegasus_4.5.2-4+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/funding_citing_usage.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="cpu_affinity_condor.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="usage_statistics.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="chapter" title="Chapter 17. Funding, citing, and anonymous usage statistics">
<div class="titlepage"><div><div><h2 class="title">
<a name="funding_citing_usage"></a>Chapter 17. Funding, citing, and anonymous usage statistics</h2></div></div></div>
<div class="toc"><dl>
<dt><span class="section"><a href="funding_citing_usage.php#citing">17.1. Citing Pegasus in Academic Works</a></span></dt>
<dt><span class="section"><a href="usage_statistics.php">17.2. Usage Statistics Collection</a></span></dt>
</dl></div>
<div class="section" title="17.1. Citing Pegasus in Academic Works">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="citing"></a>17.1. Citing Pegasus in Academic Works</h2></div></div></div>
<p>The preferred generic way to cite Pegasus is:</p>
<p><span class="emphasis"><em>Pegasus: a Framework for Mapping Complex Scientific
    Workflows onto Distributed Systems, Ewa Deelman, Gurmeet Singh, Mei-Hui
    Su, James Blythe, Yolanda Gil, Carl Kesselman, Gaurang Mehta, Karan Vahi,
    G. Bruce Berriman, John Good, Anastasia Laity, Joseph C. Jacob, Daniel S.
    Katz. Scientific Programming Journal, Vol 13(3), 2005, Pages
    219-237.</em></span></p>
</div>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="cpu_affinity_condor.php">Prev</a> </td>
<td width="20%" align="center"> </td>
<td width="40%" align="right"> <a accesskey="n" href="usage_statistics.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">16.5. Slot Partitioning and CPU Affinity in Condor </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 17.2. Usage Statistics Collection</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>
